@@ -20,7 +20,9 @@ class CALENDARSUPPORT_EXPORT FreePeriodModel : public QAbstractTableModel
 {
     Q_OBJECT
 public:
-    enum Roles { PeriodRole = Qt::UserRole };
+    enum Roles {
+        PeriodRole = Qt::UserRole
+    };
     explicit FreePeriodModel(QObject *parent = nullptr);
     ~FreePeriodModel() override;
 
